pub fn init_user_config() -> Result<(PathBuf, bool), ConfigError>Expand description
Creates ~/.config/codei/config.toml if it does not exist.
Returns the path and whether a new file was created.
pub fn init_user_config() -> Result<(PathBuf, bool), ConfigError>Creates ~/.config/codei/config.toml if it does not exist.
Returns the path and whether a new file was created.